@@ -3,4 +3,6 @@
 # @File : __init__.py.py
 # @Author : xingc
 # @Desc : None
+from .date import current_date
 from .jsons import jsonpath, format_json
+from .hash import md5
